==> 0.6b2.tar.gz: aseprite/src/jinete/jinete.h <==
/* Jinete - a GUI library
 * Copyright (C) 2003-2008 David A. Capello.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *   * Neither the name of the Jinete nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef JINETE_H
#define JINETE_H

#include "jinete/jaccel.h"
#include "jinete/jalert.h"
#include "jinete/jbase.h"
#include "jinete/jbox.h"
#include "jinete/jbutton.h"
#include "jinete/jclipboard.h"
#include "jinete/jcombobox.h"
#include "jinete/jdraw.h"
#include "jinete/jentry.h"
#include "jinete/jgrid.h"
#include "jinete/jfile.h"
#include "jinete/jfilesel.h"
#include "jinete/jfont.h"
#include "jinete/jhook.h"
#include "jinete/jimage.h"
#include "jinete/jlabel.h"
#include "jinete/jlist.h"
#include "jinete/jlistbox.h"
#include "jinete/jmanager.h"
#include "jinete/jmenu.h"
#include "jinete/jmessage.h"
#include "jinete/jmutex.h"
#include "jinete/jpanel.h"
#include "jinete/jquickmenu.h"
#include "jinete/jrect.h"
#include "jinete/jregion.h"
#include "jinete/jscroll.h"
#include "jinete/jsep.h"
#include "jinete/jslider.h"
#include "jinete/jstream.h"
#include "jinete/jsystem.h"
#include "jinete/jtextbox.h"
#include "jinete/jtheme.h"
#include "jinete/jthread.h"
#include "jinete/jtooltips.h"
#include "jinete/jview.h"
#include "jinete/jwidget.h"
#include "jinete/jwindow.h"
#include "jinete/jxml.h"

#endif /* JINETE_H */

==> 0.7.1.tar.gz: aseprite/src/jinete/jinete.h <==
/* Jinete - a GUI library
 * Copyright (C) 2003-2009 David Capello.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *   * Neither the name of the author nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef JINETE_H
#define JINETE_H

#include "jinete/jaccel.h"
#include "jinete/jalert.h"
#include "jinete/jbase.h"
#include "jinete/jbox.h"
#include "jinete/jbutton.h"
#include "jinete/jclipboard.h"
#include "jinete/jcombobox.h"
#include "jinete/jdraw.h"
#include "jinete/jentry.h"
#include "jinete/jgrid.h"
#include "jinete/jfile.h"
#include "jinete/jfilesel.h"
#include "jinete/jfont.h"
#include "jinete/jhook.h"
#include "jinete/jimage.h"
#include "jinete/jlabel.h"
#include "jinete/jlist.h"
#include "jinete/jlistbox.h"
#include "jinete/jmanager.h"
#include "jinete/jmenu.h"
#include "jinete/jmessage.h"
#include "jinete/jmutex.h"
#include "jinete/jpanel.h"
#include "jinete/jquickmenu.h"
#include "jinete/jrect.h"
#include "jinete/jregion.h"
#include "jinete/jsep.h"
#include "jinete/jslider.h"
#include "jinete/jstream.h"
#include "jinete/jstring.h"
#include "jinete/jsystem.h"
#include "jinete/jtextbox.h"
#include "jinete/jtheme.h"
#include "jinete/jthread.h"
#include "jinete/jtooltips.h"
#include "jinete/jview.h"
#include "jinete/jwidget.h"
#include "jinete/jwindow.h"
#include "jinete/jxml.h"

#endif /* JINETE_H */
